summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorabarth@chromium.org <abarth@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-08-20 06:56:46 +0000
committerabarth@chromium.org <abarth@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-08-20 06:56:46 +0000
commit6ac97bf5fb39946a9c224ddb07f233dc2c3eb66a (patch)
treeb003400265c9ab444e63fe864e80c1bdbaabc5ea
parent2bdf2daabad65100675cb6770667f846083f64b1 (diff)
downloadchromium_src-6ac97bf5fb39946a9c224ddb07f233dc2c3eb66a.zip
chromium_src-6ac97bf5fb39946a9c224ddb07f233dc2c3eb66a.tar.gz
chromium_src-6ac97bf5fb39946a9c224ddb07f233dc2c3eb66a.tar.bz2
Revert 23805.
git-svn-id: svn://svn.chromium.org/chrome/trunk/src@23807 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--chrome/browser/tab_contents/render_view_host_delegate_helper.cc2
-rw-r--r--chrome/common/chrome_switches.cc5
-rw-r--r--chrome/common/chrome_switches.h2
3 files changed, 5 insertions, 4 deletions
diff --git a/chrome/browser/tab_contents/render_view_host_delegate_helper.cc b/chrome/browser/tab_contents/render_view_host_delegate_helper.cc
index 458b1b2..5146caf 100644
--- a/chrome/browser/tab_contents/render_view_host_delegate_helper.cc
+++ b/chrome/browser/tab_contents/render_view_host_delegate_helper.cc
@@ -175,7 +175,7 @@ WebPreferences RenderViewHostDelegateHelper::GetWebkitPrefs(
web_prefs.remote_fonts_enabled =
command_line.HasSwitch(switches::kEnableRemoteFonts);
web_prefs.xss_auditor_enabled =
- !command_line.HasSwitch(switches::kDisableXSSAuditor);
+ command_line.HasSwitch(switches::kEnableXSSAuditor);
web_prefs.application_cache_enabled =
command_line.HasSwitch(switches::kEnableApplicationCache);
diff --git a/chrome/common/chrome_switches.h b/chrome/common/chrome_switches.h
index d38a0d9..e3ff1a9 100644
--- a/chrome/common/chrome_switches.h
+++ b/chrome/common/chrome_switches.h
@@ -199,7 +199,7 @@ extern const wchar_t kFileDescriptorLimit[];
extern const wchar_t kEnableMonitorProfile[];
-extern const wchar_t kDisableXSSAuditor[];
+extern const wchar_t kEnableXSSAuditor[];
#if defined(OS_POSIX)
extern const wchar_t kEnableCrashReporter[];
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index 70a4ad5..4204e27 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -525,8 +525,9 @@ const wchar_t kFileDescriptorLimit[] = L"file-descriptor-limit";
// to be sRGB.
const wchar_t kEnableMonitorProfile[] = L"enable-monitor-profile";
-// Disable WebKit's XSSAuditor. The XSSAuditor mitigates reflective XSS.
-const wchar_t kDisableXSSAuditor[] = L"disable-xss-auditor";
+// Enable WebKit's XSSAuditor to mitigate reflective XSS. The XSSAuditor is
+// still experimental.
+const wchar_t kEnableXSSAuditor[] = L"enable-xss-auditor";
#if defined(OS_POSIX)
// A flag, generated internally by Chrome for renderer and other helper process